@@ -8,6 +8,8 @@
 
 #include "AdaptiveByteStream.h"
 
+#include "common/AdaptiveStream.h"
+
 // AP4_ByteStream methods
 AP4_Result CAdaptiveByteStream::ReadPartial(void* buffer, AP4_Size bytesToRead, AP4_Size& bytesRead)
 {
@@ -23,6 +25,11 @@ AP4_Result CAdaptiveByteStream::WritePartial(const void* buffer,
   return AP4_ERROR_NOT_SUPPORTED;
 }
 
+bool CAdaptiveByteStream::ReadFull(std::vector<uint8_t>& buffer)
+{
+  return m_adStream->ReadFullBuffer(buffer);
+}
+
 AP4_Result CAdaptiveByteStream::Seek(AP4_Position position)
 {
   return m_adStream->seek(position) ? AP4_SUCCESS : AP4_ERROR_NOT_SUPPORTED;
@@ -39,11 +46,17 @@ AP4_Result CAdaptiveByteStream::GetSize(AP4_LargeSize& size)
   return AP4_ERROR_NOT_SUPPORTED;
 }
 
-AP4_Result CAdaptiveByteStream::GetSegmentSize(size_t& size)
+bool CAdaptiveByteStream::waitingForSegment() const
 {
-  if (m_adStream->ensureSegment() && m_adStream->retrieveCurrentSegmentBufferSize(size))
-  {
-    return AP4_SUCCESS;
-  }
-  return AP4_ERROR_EOS;
+  return m_adStream->waitingForSegment();
+}
+
+void CAdaptiveByteStream::FixateInitialization(bool on)
+{
+  m_adStream->FixateInitialization(on);
+}
+
+void CAdaptiveByteStream::SetSegmentFileOffset(uint64_t offset)
+{
+  m_adStream->SetSegmentFileOffset(offset);
 }
