@@ -8,8 +8,6 @@
 
 #pragma once
 
-#include "common/AdaptiveStream.h"
-
 #include <bento4/Ap4.h>
 
 #ifdef INPUTSTREAM_TEST_BUILD
@@ -18,6 +16,12 @@
 #include <kodi/AddonBase.h>
 #endif
 
+// forwards
+namespace adaptive
+{
+class AdaptiveStream;
+}
+
 class ATTR_DLL_LOCAL CAdaptiveByteStream : public AP4_ByteStream
 {
 public:
@@ -29,17 +33,24 @@ public:
   AP4_Result WritePartial(const void* buffer,
                           AP4_Size bytesToWrite,
                           AP4_Size& bytesWritten) override;
+
+  /*!
+  * \brief Read in full the stream.
+  * \param buffer[OUT] The full data buffer bytes
+  * \return True if has success, otherwise false
+  */
+  bool ReadFull(std::vector<uint8_t>& buffer);
+
   AP4_Result Seek(AP4_Position position) override;
   AP4_Result Tell(AP4_Position& position) override;
   AP4_Result GetSize(AP4_LargeSize& size) override;
-  AP4_Result GetSegmentSize(size_t& size);
 
   // AP4_Referenceable methods
   void AddReference() override{};
   void Release() override{};
-  bool waitingForSegment() const { return m_adStream->waitingForSegment(); }
-  void FixateInitialization(bool on) { m_adStream->FixateInitialization(on); }
-  void SetSegmentFileOffset(uint64_t offset) { m_adStream->SetSegmentFileOffset(offset); }
+  bool waitingForSegment() const;
+  void FixateInitialization(bool on);
+  void SetSegmentFileOffset(uint64_t offset);
 
 protected:
   adaptive::AdaptiveStream* m_adStream;
