@@ -13,6 +13,7 @@
 #include <bento4/Ap4Types.h>
 
 #include <string>
+#include <vector>
 
 #ifdef INPUTSTREAM_TEST_BUILD
 #include "test/KodiStubs.h"
@@ -23,13 +24,13 @@
 class ATTR_DLL_LOCAL AESDecrypter : public IAESDecrypter
 {
 public:
-  AESDecrypter(const std::string& licenseKey) : m_licenseKey(licenseKey){};
+  AESDecrypter(std::string_view licenseKey) : m_licenseKey(licenseKey) {}
   virtual ~AESDecrypter() = default;
 
   void decrypt(const AP4_UI08* aes_key,
                const AP4_UI08* aes_iv,
                const AP4_UI08* src,
-               std::string& dst,
+               std::vector<uint8_t>& dst,
                size_t dstOffset,
                size_t& dataSize,
                bool lastChunk);
