@@ -15,7 +15,7 @@ class ATTR_DLL_LOCAL AVCCodecHandler : public CodecHandler
 public:
   AVCCodecHandler(AP4_SampleDescription* sd);
   bool ExtraDataToAnnexB() override;
-  void UpdatePPSId(AP4_DataBuffer const& buffer) override;
+  void UpdatePPSId(const AP4_DataBuffer& buffer) override;
   bool GetInformation(kodi::addon::InputstreamInfo& info) override;
   STREAMCODEC_PROFILE GetProfile() override { return m_codecProfile; };
 
