@@ -8,6 +8,10 @@
 
 #include "VP9CodecHandler.h"
 
+#include "utils/Utils.h"
+
+using namespace UTILS;
+
 VP9CodecHandler::VP9CodecHandler(AP4_SampleDescription* sd) : CodecHandler(sd)
 {
   if (AP4_Atom* atom = m_sampleDescription->GetDetails().GetChild(AP4_ATOM_TYPE_VPCC, 0))
@@ -17,3 +21,12 @@ VP9CodecHandler::VP9CodecHandler(AP4_SampleDescription* sd) : CodecHandler(sd)
       m_extraData.SetData(vpcc->GetData().GetData(), vpcc->GetData().GetDataSize());
   }
 }
+
+bool VP9CodecHandler::GetInformation(kodi::addon::InputstreamInfo& info)
+{
+  bool isChanged = CodecHandler::GetInformation(info);
+
+  isChanged |= UpdateInfoCodecName(info, CODEC::NAME_VP9);
+
+  return isChanged;
+}
