@@ -8,18 +8,21 @@
 
 #include "ChooserDefault.h"
 
-#include "../utils/SettingsUtils.h"
-#include "../utils/log.h"
+#include "AdaptationSet.h"
+#include "CompKodiProps.h"
+#include "CompSettings.h"
 #include "ReprSelector.h"
+#include "Representation.h"
+#include "SrvBroker.h"
+#include "utils/log.h"
 
 #include <algorithm>
 #include <cmath>
 #include <numeric>
 #include <string_view>
 
-using namespace adaptive;
 using namespace CHOOSER;
-using namespace UTILS;
+using namespace PLAYLIST;
 
 namespace
 {
@@ -33,30 +36,21 @@ CRepresentationChooserDefault::CRepresentationChooserDefault()
   LOG::Log(LOGDEBUG, "[Repr. chooser] Type: Default");
 }
 
-void CRepresentationChooserDefault::Initialize(const UTILS::PROPERTIES::ChooserProps& props)
+void CRepresentationChooserDefault::Initialize(const ADP::KODI_PROPS::ChooserProps& props)
 {
-  std::pair<int, int> res;
-  if (SETTINGS::ParseResolutionLimit(kodi::addon::GetSettingString("adaptivestream.res.max"), res))
-  {
-    m_screenResMax = res;
-  }
-  if (SETTINGS::ParseResolutionLimit(kodi::addon::GetSettingString("adaptivestream.res.secure.max"),
-                                     res))
-  {
-    m_screenResSecureMax = res;
-  }
+  auto& settings = CSrvBroker::GetSettings();
 
-  m_bandwidthInitAuto = kodi::addon::GetSettingBoolean("adaptivestream.bandwidth.init.auto");
-  m_bandwidthInit =
-      static_cast<uint32_t>(kodi::addon::GetSettingInt("adaptivestream.bandwidth.init") * 1000);
+  m_screenResMax = settings.GetResMax();
+  m_screenResSecureMax = settings.GetResSecureMax();
 
-  m_bandwidthMin =
-      static_cast<uint32_t>(kodi::addon::GetSettingInt("adaptivestream.bandwidth.min") * 1000);
-  m_bandwidthMax =
-      static_cast<uint32_t>(kodi::addon::GetSettingInt("adaptivestream.bandwidth.max") * 1000);
+  m_bandwidthInitAuto = settings.IsBandwidthInitAuto();
+  m_bandwidthInit = settings.GetBandwidthInit();
 
-  m_ignoreScreenRes = kodi::addon::GetSettingBoolean("overrides.ignore.screen.res");
-  m_ignoreScreenResChange = kodi::addon::GetSettingBoolean("overrides.ignore.screen.res.change");
+  m_bandwidthMin = settings.GetBandwidthMin();
+  m_bandwidthMax = settings.GetBandwidthMax();
+
+  m_ignoreScreenRes = settings.IsIgnoreScreenRes();
+  m_ignoreScreenResChange = settings.IsIgnoreScreenResChange();
 
   // Override settings with Kodi/video add-on properties
 
@@ -89,6 +83,12 @@ void CRepresentationChooserDefault::Initialize(const UTILS::PROPERTIES::ChooserP
            m_ignoreScreenResChange);
 }
 
+void CRepresentationChooserDefault::SetSecureSession(const bool isSecureSession)
+{
+  m_isSecureSession = isSecureSession;
+  RefreshResolution();
+}
+
 void CRepresentationChooserDefault::PostInit()
 {
   RefreshResolution();
@@ -114,21 +114,28 @@ void CRepresentationChooserDefault::PostInit()
            m_screenWidth, m_screenHeight, m_bandwidthCurrent);
 }
 
+void CRepresentationChooserDefault::CheckResolution()
+{
+  if (m_screenWidth != m_screenCurrentWidth || m_screenHeight != m_screenCurrentHeight)
+  {
+    // Update the screen resolution values only after n seconds
+    // to prevent too fast update when Kodi window will be resized
+    if (m_screenResLastUpdate.has_value() &&
+        std::chrono::duration_cast<std::chrono::seconds>(std::chrono::steady_clock::now() -
+                                                         *m_screenResLastUpdate)
+                .count() < SCREEN_RES_REFRESH_SECS)
+    {
+      return;
+    }
+    RefreshResolution();
+    m_screenResLastUpdate = std::chrono::steady_clock::now();
+    LOG::Log(LOGDEBUG, "[Repr. chooser] Screen resolution has changed: %ix%i", m_screenCurrentWidth,
+             m_screenCurrentHeight);
+  }
+}
+
 void CRepresentationChooserDefault::RefreshResolution()
 {
-  if (m_screenWidth == m_screenCurrentWidth && m_screenHeight == m_screenCurrentHeight)
-    return;
-
-  // Update the screen resolution values only after n seconds
-  // to prevent too fast update when Kodi window will be resized
-  if (m_screenResLastUpdate.has_value() &&
-      std::chrono::duration_cast<std::chrono::seconds>(std::chrono::steady_clock::now() -
-                                                       *m_screenResLastUpdate)
-              .count() < SCREEN_RES_REFRESH_SECS)
-  {
-    return;
-  }
-
   m_screenWidth = m_ignoreScreenRes ? 16384 : m_screenCurrentWidth;
   m_screenHeight = m_ignoreScreenRes ? 16384 : m_screenCurrentHeight;
 
@@ -143,10 +150,6 @@ void CRepresentationChooserDefault::RefreshResolution()
     if (m_screenHeight > userResLimit.second)
       m_screenHeight = userResLimit.second;
   }
-
-  LOG::Log(LOGDEBUG, "[Repr. chooser] Screen resolution has changed: %ix%i", m_screenCurrentWidth,
-           m_screenCurrentHeight);
-  m_screenResLastUpdate = std::chrono::steady_clock::now();
 }
 
 void CRepresentationChooserDefault::SetDownloadSpeed(const double speed)
@@ -176,58 +179,55 @@ void CRepresentationChooserDefault::SetDownloadSpeed(const double speed)
     m_bandwidthCurrentLimited = m_bandwidthMax;
 }
 
-AdaptiveTree::Representation* CRepresentationChooserDefault::GetNextRepresentation(
-    AdaptiveTree::AdaptationSet* adp, AdaptiveTree::Representation* currentRep)
+PLAYLIST::CRepresentation* CRepresentationChooserDefault::GetNextRepresentation(
+    PLAYLIST::CAdaptationSet* adp, PLAYLIST::CRepresentation* currentRep)
 {
-  if (!m_ignoreScreenRes && !m_ignoreScreenResChange)
-    RefreshResolution();
+  bool isVideoStreamType = adp->GetStreamType() == StreamType::VIDEO;
+
+  if (isVideoStreamType && !m_ignoreScreenRes && !m_ignoreScreenResChange)
+    CheckResolution();
 
   CRepresentationSelector selector(m_screenWidth, m_screenHeight);
   uint32_t bandwidth;
 
   // From bandwidth take in consideration:
   // 90% of bandwidth for video - 10 % for other
-  if (adp->type_ == AdaptiveTree::VIDEO)
+  if (isVideoStreamType)
     bandwidth = static_cast<uint32_t>(m_bandwidthCurrentLimited * 0.9);
   else
     bandwidth = static_cast<uint32_t>(m_bandwidthCurrentLimited * 0.1);
 
-  if (adp->type_ == AdaptiveTree::VIDEO) // To avoid fill too much the log
-  {
-    LOG::Log(LOGDEBUG, "[Repr. chooser] Current average bandwidth: %u bit/s (filtered to %u bit/s)",
-             m_bandwidthCurrent, bandwidth);
-  }
-
-  AdaptiveTree::Representation* nextRep{nullptr};
+  CRepresentation* nextRep{nullptr};
   int bestScore{-1};
 
-  for (auto rep : adp->representations_)
+  for (auto& rep : adp->GetRepresentations())
   {
-    if (!rep)
-      continue;
-
-    int score{std::abs(rep->width_ * rep->height_ - m_screenWidth * m_screenHeight)};
+    int score{std::abs(rep->GetWidth() * rep->GetHeight() - m_screenWidth * m_screenHeight)};
 
     if (!m_isForceStartsMaxRes)
     {
-      if (rep->bandwidth_ > bandwidth)
+      if (rep->GetBandwidth() > bandwidth)
         continue;
 
-      score += static_cast<int>(std::sqrt(bandwidth - rep->bandwidth_));
+      score += static_cast<int>(std::sqrt(bandwidth - rep->GetBandwidth()));
     }
 
     if (bestScore == -1 || score < bestScore)
     {
       bestScore = score;
-      nextRep = rep;
+      nextRep = rep.get();
     }
   }
 
   if (!nextRep)
     nextRep = selector.Lowest(adp);
 
-  if (adp->type_ == AdaptiveTree::VIDEO)
+  if (isVideoStreamType) // Only video, to avoid fill too much the log
+  {
+    LOG::Log(LOGDEBUG, "[Repr. chooser] Current average bandwidth: %u bit/s (filtered to %u bit/s)",
+             m_bandwidthCurrent, bandwidth);
     LogDetails(currentRep, nextRep);
+  }
 
   if (m_isForceStartsMaxRes)
     m_isForceStartsMaxRes = false;
