@@ -10,6 +10,8 @@
 
 #include "Chooser.h"
 
+#include <utility>
+
 namespace CHOOSER
 {
 /*!
@@ -22,23 +24,19 @@ public:
   CRepresentationChooserManualOSD();
   ~CRepresentationChooserManualOSD() override {}
 
-  virtual void Initialize(const UTILS::PROPERTIES::ChooserProps& props) override;
-
+  virtual void Initialize(const ADP::KODI_PROPS::ChooserProps& props) override;
+  virtual void SetSecureSession(const bool isSecureSession) override;
   virtual void PostInit() override;
 
-  virtual UTILS::SETTINGS::StreamSelection GetStreamSelectionMode() override
-  {
-    return m_streamSelectionMode;
-  }
+  virtual StreamSelection GetStreamSelectionMode() override { return m_streamSelectionMode; }
 
-  adaptive::AdaptiveTree::Representation* GetNextRepresentation(
-      adaptive::AdaptiveTree::AdaptationSet* adp,
-      adaptive::AdaptiveTree::Representation* currentRep) override;
+  PLAYLIST::CRepresentation* GetNextRepresentation(PLAYLIST::CAdaptationSet* adp,
+                                                   PLAYLIST::CRepresentation* currentRep) override;
 
 protected:
   void RefreshResolution();
 
-  UTILS::SETTINGS::StreamSelection m_streamSelectionMode{UTILS::SETTINGS::StreamSelection::AUTO};
+  StreamSelection m_streamSelectionMode = StreamSelection::AUTO;
 
   int m_screenWidth{0};
   int m_screenHeight{0};
