@@ -6,10 +6,11 @@
  *  See LICENSES/README.md for more information.
  */
 
-#include "../ADTSReader.h"
-#include "../AdaptiveByteStream.h"
-#include "../TSReader.h"
 #include "SampleReader.h"
+#include "demuxers/ADTSReader.h"
+
+// forwards
+class CAdaptiveByteStream;
 
 class ATTR_DLL_LOCAL CADTSSampleReader : public ISampleReader, public ADTSReader
 {
@@ -29,10 +30,7 @@ public:
   }
   bool TimeSeek(uint64_t pts, bool preceeding) override;
   void SetPTSOffset(uint64_t offset) override { m_ptsOffs = offset; }
-  uint64_t GetStartPTS() const override { return m_startPts; }
-  void SetStartPTS(uint64_t pts) override { m_startPts = pts; }
   int64_t GetPTSDiff() const override { return m_ptsDiff; }
-  bool GetNextFragmentInfo(uint64_t& ts, uint64_t& dur) override { return false; }
   uint32_t GetTimeScale() const override { return 90000; }
   AP4_UI32 GetStreamId() const override { return m_streamId; }
   AP4_Size GetSampleDataSize() const override { return GetPacketSize(); }
@@ -47,6 +45,5 @@ private:
   uint64_t m_pts{0};
   int64_t m_ptsDiff{0};
   uint64_t m_ptsOffs{~0ULL};
-  uint64_t m_startPts{STREAM_NOPTS_VALUE};
   CAdaptiveByteStream* m_adByteStream;
 };
