@@ -6,9 +6,11 @@
  *  See LICENSES/README.md for more information.
  */
 
-#include "../AdaptiveByteStream.h"
-#include "../WebmReader.h"
 #include "SampleReader.h"
+#include "demuxers/WebmReader.h"
+
+// forwards
+class CAdaptiveByteStream;
 
 class ATTR_DLL_LOCAL CWebmSampleReader : public ISampleReader, public WebmReader
 {
@@ -19,7 +21,7 @@ public:
   bool EOS() const override { return m_eos; }
   uint64_t DTS() const override { return m_dts; }
   uint64_t PTS() const override { return m_pts; }
-  bool Initialize() override;
+  bool Initialize(SESSION::CStream* stream) override;
   AP4_Result Start(bool& bStarted) override;
   AP4_Result ReadSample() override;
   void Reset(bool bEOS) override;
@@ -29,10 +31,7 @@ public:
   }
   bool TimeSeek(uint64_t pts, bool preceeding) override;
   void SetPTSOffset(uint64_t offset) override { m_ptsOffs = offset; }
-  uint64_t GetStartPTS() const override { return m_startPts; }
-  void SetStartPTS(uint64_t pts) override { m_startPts = pts; }
   int64_t GetPTSDiff() const override { return m_ptsDiff; }
-  bool GetNextFragmentInfo(uint64_t& ts, uint64_t& dur) override { return false; }
   uint32_t GetTimeScale() const override { return 1000; }
   AP4_UI32 GetStreamId() const override { return m_streamId; }
   AP4_Size GetSampleDataSize() const override { return GetPacketSize(); }
@@ -46,7 +45,6 @@ private:
   uint64_t m_dts{0};
   uint64_t m_ptsOffs{~0ULL};
   int64_t m_ptsDiff{0};
-  uint64_t m_startPts{STREAM_NOPTS_VALUE};
   bool m_eos{false};
   bool m_started{false};
   CAdaptiveByteStream* m_adByteStream;
