@@ -16,6 +16,11 @@ namespace UTILS
 {
 namespace FILESYS
 {
+#ifdef WIN32
+constexpr char SEPARATOR = '\\';
+#else
+constexpr char SEPARATOR = '/';
+#endif
 
 /*!
  * \brief Save the data into a file
@@ -24,7 +29,7 @@ namespace FILESYS
  * \param overwrite If true will overwrite the existing file.
  * \return True if success, otherwise false.
  */
-bool SaveFile(std::string_view filePath, std::string_view data, bool overwrite);
+bool SaveFile(const std::string filePath, const std::string& data, bool overwrite);
 
 /*!
  * \brief Combine a path with another one
@@ -32,7 +37,7 @@ bool SaveFile(std::string_view filePath, std::string_view data, bool overwrite);
  * \param filePath The path to be combined, like filename or another path.
  * \return The combined path.
  */
-std::string PathCombine(std::string path, std::string filePath);
+std::string PathCombine(std::string_view path, std::string_view filePath);
 
 /*!
  * \brief Get the user-related data folder of the addon.
@@ -40,6 +45,12 @@ std::string PathCombine(std::string path, std::string filePath);
  */
 std::string GetAddonUserPath();
 
+/*!
+ * \brief Get the data folder of the addon.
+ * \return The path.
+ */
+std::string GetAddonPath();
+
 /*!
  * \brief Check for duplicates for the file path, and change the filename
  *        based on the number of duplicate files.
@@ -60,5 +71,12 @@ bool CheckDuplicateFilePath(std::string& filePath, uint32_t filesLimit = 0);
  */
 bool RemoveDirectory(std::string_view path, bool recursive = true);
 
+/*!
+ * \brief Get the file extension from a filename.
+ * \param path The filename with or without a path.
+ * \return The file extension if found, otherwise empty string.
+ */
+std::string GetFileExtension(std::string path);
+
 } // namespace FILESYS
 } // namespace UTILS
