@@ -78,6 +78,29 @@ bool isUrl(std::string url,
   return true;
 }
 
+void RemovePrefixSingleDot(std::string& url)
+{
+  size_t pos{0};
+  // Remove occurrences of "/./" preserving the separator
+  while ((pos = url.find("/./")) != std::string::npos)
+  {
+    url.erase(pos, 2);
+  }
+
+  if (StringUtils::EndsWith(url, "/."))
+    url.pop_back(); // Delete the dot and preserve the separator
+}
+
+void RemovePrefixDoubleDot(std::string& url)
+{
+  size_t pos{0};
+  // Remove occurrences of "/../" preserving the separator
+  while ((pos = url.find("/../")) != std::string::npos)
+  {
+    url.erase(pos, 3);
+  }
+}
+
 /*
  * \brief Remove and resolve special dot's from the end of the url.
  *        e.g. "http://foo.bar/sub1/sub2/.././" will result "http://foo.bar/sub1/"
@@ -88,18 +111,18 @@ std::string RemoveDotSegments(std::string url)
   size_t numSegsRemove{0};
   size_t currPos{0};
   size_t startPos{url.size() - 2};
-  while ((currPos = url.rfind("/", startPos)) != std::string::npos)
+  while ((currPos = url.rfind('/', startPos)) != std::string::npos)
   {
     // Stop to ignore "/../" from the start of string, e.g. ignored --> "../../something/../" <-- handled
-    if (url.substr(currPos + 1, startPos - currPos + 1) != PREFIX_DOUBLE_DOT)
+    if (currPos == 0 || url.substr(currPos + 1, startPos - currPos + 1) != PREFIX_DOUBLE_DOT)
       break;
     startPos = currPos - 1;
     numSegsRemove++;
   }
 
   // Remove special prefixes
-  UTILS::STRING::ReplaceAll(url, PREFIX_DOUBLE_DOT, "");
-  UTILS::STRING::ReplaceAll(url, PREFIX_SINGLE_DOT, "");
+  RemovePrefixSingleDot(url);
+  RemovePrefixDoubleDot(url);
 
   size_t addrsStartPos{0};
   if (IsUrlAbsolute(url))
@@ -257,18 +280,16 @@ std::string UTILS::URL::GetBaseDomain(std::string url)
     if (paramsPos != std::string::npos)
       url.erase(paramsPos);
 
-    const size_t domainStartPos = url.find("://") + 3;
-    // Try remove url port number and path
-    const size_t port = url.find_first_of(':', domainStartPos);
-    if (port != std::string::npos)
-      url.erase(port);
-    else
-    {
-      // Try remove the path
-      const size_t slashPos = url.find_first_of('/', domainStartPos);
-      if (slashPos != std::string::npos)
-        url.erase(slashPos);
-    }
+    const size_t schemeEndPos = url.find("://");
+    if (schemeEndPos == std::string::npos)
+      return ""; // Not valid
+
+    const size_t domainStartPos = schemeEndPos + 3;
+    const size_t pathPos = url.find_first_of('/', domainStartPos);
+
+    if (pathPos != std::string::npos)
+      url.erase(pathPos); // remove from slash
+
     return url;
   }
   return "";
@@ -284,8 +305,6 @@ std::string UTILS::URL::Join(std::string baseUrl, std::string relativeUrl)
 
   if (relativeUrl == ".") // Ignore single dot
     relativeUrl.clear();
-  else if (relativeUrl.compare(0, 2, PREFIX_SINGLE_DOT) == 0) // Ignore prefix ./
-    relativeUrl.erase(0, 2);
 
   // Sanitize for missing backslash
   if (relativeUrl == ".." || StringUtils::EndsWith(relativeUrl, "/.."))
